"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.cli = void 0;
const micro_1 = __importDefault(require("micro"));
const cmd_ts_1 = require("cmd-ts");
function cli({ version, createHandler, }) {
    const cmd = (0, cmd_ts_1.command)({
        name: 'graphql-rss-parser',
        version,
        args: {
            port: (0, cmd_ts_1.option)({
                short: 'p',
                long: 'port',
                description: 'Port to listen to',
                env: 'PORT',
                type: cmd_ts_1.number,
                defaultValue() {
                    return 3000;
                },
            }),
            host: (0, cmd_ts_1.option)({
                short: 'H',
                long: 'host',
                env: 'HOST',
                description: 'Host to listen to',
                defaultValue() {
                    return '0.0.0.0';
                },
            }),
            sentryDsn: (0, cmd_ts_1.option)({
                short: 'D',
                long: 'sentry-dsn',
                description: 'SENTRY DSN. This is used to configure logging with sentry.io',
                env: 'SENTRY_ENV',
                type: (0, cmd_ts_1.optional)(cmd_ts_1.string),
                defaultValue() {
                    return undefined;
                },
            }),
        },
        handler: (args) => {
            const server = (0, micro_1.default)(createHandler({
                version,
                sentryDsn: args.sentryDsn,
            }));
            console.log(`Starting graphql-rss-parser v${version}`);
            server.listen(args.port);
        },
    });
    return (0, cmd_ts_1.run)(cmd, process.argv.slice(2));
}
exports.cli = cli;
//# sourceMappingURL=cli.js.map