"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseFromQuery = exports.parseFromString = void 0;
const parsers_1 = require("../parsers");
const transform_1 = __importDefault(require("../transform"));
const request_1 = __importDefault(require("../request"));
const errors_1 = require("../errors");
async function parse(parser, text) {
    const parsed = await parsers_1.parsers[parser](text);
    if (!parsed)
        throw new errors_1.EmptyParserOutputError();
    return (0, transform_1.default)(parsed);
}
async function parseFromString({ content, parser, }) {
    if (parser) {
        return parse(parser, content);
    }
    else {
        for (let i = 0; i < parsers_1.parserKeys.length; i++) {
            try {
                const parserKey = parsers_1.parserKeys[i];
                if (!parserKey) {
                    continue;
                }
                return await parse(parserKey, content);
            }
            catch (error) {
                if (i < parsers_1.parserKeys.length - 1) {
                    continue;
                }
                throw error;
            }
        }
        throw new errors_1.BaseError('No parsers worked', 'no-parser');
    }
}
exports.parseFromString = parseFromString;
async function parseFromQuery({ url, parser, endTime, startTime, }) {
    const response = await (0, request_1.default)(url);
    const contentType = (response.contentType ? response.contentType.split(';')[0] : '') || '';
    const isJsonFeed = ['application/json', 'application/feed+json'].includes(contentType);
    const parsed = await parseFromString({
        content: response.text,
        parser: isJsonFeed ? 'JSON_FEED_V1' : parser,
    });
    parsed.items = parsed.items?.filter((item) => {
        if (item == null) {
            return false;
        }
        if (item.date_published &&
            endTime &&
            new Date(endTime) < new Date(item.date_published)) {
            return false;
        }
        if (item.date_published &&
            startTime &&
            new Date(startTime) > new Date(item.date_published)) {
            return false;
        }
        return true;
    });
    parsed.feed_url = parsed.feed_url || url;
    return parsed;
}
exports.parseFromQuery = parseFromQuery;
//# sourceMappingURL=feed.js.map