"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const apollo_server_micro_1 = require("apollo-server-micro");
const schema_1 = require("./schema");
const errors_1 = require("./errors");
function createHandler(options) {
    let Sentry;
    if (options.sentryDsn) {
        Sentry = require('@sentry/node');
        Sentry.init({
            dsn: options.sentryDsn,
            release: `graphql-rss-parser@${options.version}`,
            environment: process.env['NODE_ENV'],
            ignoreErrors: errors_1.sentryIgnoreErrors,
            onFatalError(error) {
                // @ts-ignore error does not have response
                console.error(error, error.response);
            },
            debug: process.env['DEBUG_SENTRY'] == 'true',
        });
    }
    // @ts-ignore response does not match
    const formatError = (0, errors_1.createErrorFormatter)(Sentry);
    const apolloServer = new apollo_server_micro_1.ApolloServer({ schema: schema_1.schema, formatError });
    return apolloServer.createHandler({ path: '/' });
}
exports.default = createHandler;
//# sourceMappingURL=index.js.map