"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.parse = void 0;
const stream_1 = require("stream");
const feedparser_1 = __importDefault(require("feedparser"));
const debug_1 = __importDefault(require("debug"));
const errors_1 = require("../errors");
const debug = (0, debug_1.default)('graphql-rss-parser:parsers:feedparser');
function parse(feed) {
    return new Promise((resolve, reject) => {
        try {
            debug('starting to parse');
            const feedparser = new feedparser_1.default({});
            feedparser.on('error', (error) => {
                debug('parsing failed with error', error);
                reject(new errors_1.ParserError(error, 'FEEDPARSER'));
            });
            let meta;
            const items = [];
            feedparser.on('readable', function () {
                meta = meta || this.meta;
                let item;
                while ((item = this.read())) {
                    items.push({
                        title: item.title,
                        content_html: item.description,
                        url: item.link,
                        tags: item.categories,
                        date_published: item.pubdate
                            ? new Date(item.pubdate).toISOString()
                            : undefined,
                        authors: item.author ? [{ name: item.author }] : [],
                        id: item.guid,
                    });
                }
            });
            feedparser.on('end', function () {
                debug('done parsing');
                if (!meta) {
                    return reject(new errors_1.EmptyParserOutputError());
                }
                resolve({
                    parser: 'FEEDPARSER',
                    title: meta.title,
                    description: meta.description,
                    home_page_url: meta.link,
                    feed_url: undefined,
                    items,
                });
            });
            const stream = new stream_1.Readable();
            stream.pipe(feedparser);
            stream.push(feed);
            stream.push(null);
        }
        catch (error) {
            debug('parsing failed with error', error);
            reject(new errors_1.ParserError(error, 'FEEDPARSER'));
        }
    }).catch((error) => {
        debug('parsing failed with error', error);
        if (error.message === 'Not a feed' ||
            error.cause.message === 'Not a feed') {
            throw new errors_1.NotAFeedError(error);
        }
        throw error;
    });
}
exports.parse = parse;
//# sourceMappingURL=feedparser.js.map