"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.parse = void 0;
const rss_parser_1 = __importDefault(require("rss-parser"));
const debug_1 = __importDefault(require("debug"));
const errors_1 = require("../errors");
const debug = (0, debug_1.default)('graphql-rss-parser:parsers:rss-parser');
const parser = new rss_parser_1.default();
function getPubDate(entry) {
    if (entry.isoDate) {
        return entry.isoDate;
    }
    try {
        return entry.pubDate
            ? new Date(entry.pubDate?.replace(/CES?T/, '(CET)')).toISOString()
            : entry.pubDate;
    }
    catch (error) {
        return entry.pubDate;
    }
}
function transform(parsed) {
    const items = parsed.items.map((item) => ({
        title: item.title,
        content_html: item.content,
        url: item.link,
        id: item.guid,
        tags: item.categories || [],
        authors: item.creator || item['dc:creator']
            ? [{ name: item.creator || item['dc:creator'] }]
            : [],
        date_published: getPubDate(item),
    }));
    return {
        parser: 'RSS_PARSER',
        title: parsed.title || '',
        description: parsed.description,
        home_page_url: parsed.link,
        feed_url: parsed.feedUrl,
        items,
    };
}
function parse(document) {
    return new Promise((resolve, reject) => {
        debug('starting to parse');
        parser.parseString(document, function (error, parsed) {
            if (error) {
                debug('parsing failed with error', error);
                if (/Line:/.test(error.message) && /Column:/.test(error.message)) {
                    return reject(new errors_1.NotAFeedError());
                }
                return reject(new errors_1.ParserError(error, 'RSS_PARSER'));
            }
            if (!parsed) {
                return reject(new errors_1.EmptyParserOutputError());
            }
            debug('done parsing');
            resolve(transform(parsed));
        });
    });
}
exports.parse = parse;
//# sourceMappingURL=rss-parser.js.map