"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.parse = void 0;
const rss_to_json_1 = require("rss-to-json");
const debug_1 = __importDefault(require("debug"));
const errors_1 = require("../errors");
const debug = (0, debug_1.default)('graphql-rss-parser:parsers:rss-to-json');
async function parse(feed) {
    try {
        debug('starting to parse');
        const parsed = await (0, rss_to_json_1.parser)(feed);
        debug('done parsing');
        return {
            parser: 'RSS_TO_JSON',
            title: parsed.title,
            description: parsed.description,
            home_page_url: parsed.link,
            feed_url: parsed.feedLink,
            items: parsed.items.map((item) => ({
                id: item.id || item.url,
                url: item.link,
                title: item.title,
                date_published: new Date(item.created).toISOString(),
                tags: typeof item.category === 'string'
                    ? [item.category]
                    : item.category || [],
                authors: item.author ? [{ name: item.author }] : [],
            })),
        };
    }
    catch (error) {
        debug('parsing failed with error', error);
        if (error.toString().includes('There are errors in your xml') ||
            error.toString().includes("Cannot read property 'item' of undefined") ||
            error
                .toString()
                .includes("Cannot read properties of undefined (reading 'item')")) {
            throw new errors_1.NotAFeedError();
        }
        throw new errors_1.ParserError(error, 'RSS_TO_JSON');
    }
}
exports.parse = parse;
//# sourceMappingURL=rss-to-json.js.map