"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const axios_1 = __importDefault(require("axios"));
const debug_1 = __importDefault(require("debug"));
const debug = (0, debug_1.default)('graphql-rss-parser:request');
const errors_1 = require("./errors");
const TIMEOUT = 30 * 1000;
async function request(url) {
    try {
        debug(`requesting ${url}`);
        const response = await (0, axios_1.default)({
            url,
            headers: {
                'User-Agent': 'graphql-rss-parser',
            },
            timeout: TIMEOUT,
            responseType: 'arraybuffer',
            transformResponse: undefined,
        });
        debug(`response from ${url} status-code=${response.status}`);
        if (!/2\d\d/.test(response.status.toString())) {
            throw new errors_1.UpstreamHttpError('Not found', response.status);
        }
        if (!response.data) {
            throw new errors_1.EmptyHttpResponseError();
        }
        return {
            text: response.data.toString(),
            status: response.status,
            contentType: response.headers['content-type'],
            headers: response.headers,
        };
    }
    catch (error) {
        debug(`request to ${url} failed with error`, error);
        if (error.response && error.response.status) {
            throw new errors_1.UpstreamHttpError('Upstream HTTP error', error.response.status);
        }
        if (error.code === 'ENOTFOUND' || error.code === 'EAI_AGAIN') {
            throw new errors_1.DnsLookupError();
        }
        if (error.code === 'ECONNREFUSED' || error.code === 'ECONNRESET') {
            throw new errors_1.ConnectionRefusedError();
        }
        if (error.code === 'ECONNABORTED' || error.code === 'ETIMEDOUT') {
            throw new errors_1.TimeoutError();
        }
        if (error.constructor === errors_1.EmptyHttpResponseError ||
            error.constructor === errors_1.UpstreamHttpError) {
            throw error;
        }
        if (/certificate|tls|ssl/.test(error.toString())) {
            throw new errors_1.UpstreamEncryptionError(error);
        }
        throw new errors_1.UnknownRequestError(error);
    }
}
exports.default = request;
//# sourceMappingURL=request.js.map